@@ -5,6 +5,7 @@ from sqlalchemy.dialects.postgresql.base import PGDialect
 from sqlalchemy.dialects.postgresql.psycopg2 import PGDialect_psycopg2
 from sqlalchemy.dialects.postgresql import INET
 from sqlalchemy.dialects.postgresql import UUID
+from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.util import warn
 import sqlalchemy.sql as sql
 
@@ -120,8 +121,10 @@ class CockroachDBDialect(PGDialect_psycopg2):
         sversion = connection.scalar("select version()")
         self._is_v2plus = " v1." not in sversion
         self._is_v21plus = self._is_v2plus and (" v2.0." not in sversion)
+        self._is_v201plus = self._is_v21plus and (" v19." not in sversion)
         self._has_native_json = self._is_v2plus
         self._has_native_jsonb = self._is_v2plus
+        self._supports_savepoints = self._is_v201plus
 
     def _get_server_version_info(self, conn):
         # PGDialect expects a postgres server version number here,
@@ -453,6 +456,9 @@ else:
         __dialect__ = 'cockroachdb'
         transactional_ddl = False
 
+    @compiles(alembic.ddl.postgresql.PostgresqlColumnType, 'cockroachdb')
+    def visit_column_type(*args, **kwargs):
+        return alembic.ddl.postgresql.visit_column_type(*args, **kwargs)
 
 # If sqlalchemy-migrate is installed, register there too.
 try:
